{% extends "base.html" %} {% block title %}Job Not Approved - {{ job_name }}{%
endblock %} {% block content %}
<h1
  style="color: #2d3748; font-size: 24px; font-weight: 600; margin: 0 0 16px 0"
>
  Job Not Approved
</h1>

<p
  style="color: #4a5568; font-size: 16px; line-height: 1.6; margin: 0 0 16px 0"
>
  {{ friendly_reason }}
</p>

{% set info_items = [ {'label': 'Job Name', 'value': job_name}, {'label':
'Status', 'value': 'Not Approved', 'badge': 'error'} ] %} {% include
'components/info_box.html' %}

<p
  style="
    color: #718096;
    font-size: 14px;
    margin-top: 30px;
    border-top: 1px solid #e2e8f0;
    padding-top: 20px;
  "
>
  If you believe this is an error, please contact the data owner to review the
  approved scripts for your account.
</p>
{% endblock %}
