"""TUI widgets for syft-bg dashboard."""

from syft_bg.tui.widgets.activity_feed import ActivityFeed
from syft_bg.tui.widgets.service_card import ServiceCard

__all__ = ["ServiceCard", "ActivityFeed"]
