"""Approval handlers for jobs and peers."""

from syft_bg.approve.handlers.job import JobApprovalHandler
from syft_bg.approve.handlers.peer import PeerApprovalHandler

__all__ = ["JobApprovalHandler", "PeerApprovalHandler"]
